@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sample2-extension.c,v 1.1.2.1 2004/02/21 23:02:07 chpe Exp $
+ *  $Id: ephy-sample2-extension.c,v 1.3 2004/02/24 17:47:23 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -126,18 +126,32 @@ dom_mouse_down_cb (EphyEmbed *embed,
 
 static void
 tab_added_cb (GtkWidget *notebook,
-	      EphyEmbed *embed,
+	      EphyTab *tab,
 	      EphySample2Extension *extension)
 {
+	EphyEmbed *embed;
+
+	g_return_if_fail (EPHY_IS_TAB (tab));
+
+	embed = ephy_tab_get_embed (tab);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
 	g_signal_connect (embed, "ge_dom_mouse_down",
 			  G_CALLBACK (dom_mouse_down_cb), extension);
 }
 
 static void
 tab_removed_cb (EphyEmbed *notebook,
-		EphyEmbed *embed,
+		EphyTab *tab,
 		EphySample2Extension *extension)
 {
+	EphyEmbed *embed;
+
+	g_return_if_fail (EPHY_IS_TAB (tab));
+
+	embed = ephy_tab_get_embed (tab);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
 	g_signal_handlers_disconnect_by_func
 		(embed, G_CALLBACK (dom_mouse_down_cb), extension);
 }
